package com.qryord.project.master.modelKind.mapper;

import com.qryord.project.master.modelKind.domain.ModelKind;

import java.util.List;

/**
 * 商品型号分类Mapper接口
 * 
 * @author ruoyi
 * @date 2022-09-30
 */
public interface ModelKindMapper
{
    /**
     * 查询商品型号分类
     * 
     * @param id 商品型号分类主键
     * @return 商品型号分类
     */
    public ModelKind selectModelKindById(Long id);

    /**
     * 查询商品型号分类列表
     * 
     * @param modelKind 商品型号分类
     * @return 商品型号分类集合
     */
    public List<ModelKind> selectModelKindList(ModelKind modelKind);

    /**
     * 新增商品型号分类
     * 
     * @param modelKind 商品型号分类
     * @return 结果
     */
    public int insertModelKind(ModelKind modelKind);

    /**
     * 修改商品型号分类
     * 
     * @param modelKind 商品型号分类
     * @return 结果
     */
    public int updateModelKind(ModelKind modelKind);

    /**
     * 删除商品型号分类
     * 
     * @param id 商品型号分类主键
     * @return 结果
     */
    public int deleteModelKindById(Long id);

    /**
     * 批量删除商品型号分类
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteModelKindByIds(String[] ids);
}
